@@ -38,7 +38,7 @@ class StepBuilder(object):
         required: bool = False,
         id: str = None,
         samplingFrequency: int = 100,
-        sensorTypes: List[str] = [],
+        sensorTypes: List[str] = ["gyroscope", "accelerometer"],
     ):
         return self.add_block(
             {
